import signal
import logging

from mqtt_presence.mqtt_presence_app import MQTTPresenceApp#, MQTTPresenceAppSingleton
from mqtt_presence.utils import Tools
from mqtt_presence.web_ui import WebUI
from mqtt_presence.console_ui import ConsoleUI
from mqtt_presence.parser import get_parser


# setup logging
logger = logging.getLogger(__name__)


def main():
    def stop(_signum, _frame):
        logger.info("🚪 Stop signal recived, exiting...")
        if mqtt_app is not None:
            mqtt_app.exit_app()
        if user_interface is not None:
            user_interface.stop()
        Tools.exit_application()

    # Parse arguments
    args = get_parser().parse_args()

    # set log directory
    Tools.setup_logger(args.log)

    user_interface = None
    mqtt_app: MQTTPresenceApp = MQTTPresenceApp(args.data)

    start_up_msg = f"🚀 mqtt-presence startup (Version: {mqtt_app.version})"
    logger.info("\n\n")
    logger.info(start_up_msg)

    signal.signal(signal.SIGINT, stop)
    signal.signal(signal.SIGTERM, stop)
    mqtt_app.start()


    logger.info("ℹ️  Selected user_interface: %s", args.ui)

    if args.ui=="webUI":
        user_interface = WebUI(mqtt_app)
    elif args.ui=="console":
        user_interface = ConsoleUI(mqtt_app)

    if user_interface is not None:
        user_interface.run_ui()


if __name__ == "__main__":
    main()
